import {Component, EventEmitter, Output, ViewChild} from "@angular/core";
import {CrePromptDialog} from "../shared/components/dialogs/dialogs";
import {Group, GroupToken} from "../shared/model/account.model";
import {FormControl, FormGroup, Validators} from "@angular/forms";
import {GroupTokenService} from "../accounts/services/group-token.service";
import {SubscribingComponent} from "../shared/components/subscribing.component";
import {ErrorService} from "../shared/service/error.service";
import {ActivatedRoute, Router} from "@angular/router";

@Component({
  selector: 'cre-group-token-list',
  templateUrl: 'list.html'
})
export class GroupTokenList extends SubscribingComponent {
  tokens$ = this.groupTokenService.all

  columns = ['id', 'name', 'groupName', 'deleteButton']

  constructor(
    private groupTokenService: GroupTokenService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }
}

@Component({
  selector: 'cre-group-token-add',
  templateUrl: 'add.html'
})
export class GroupTokenAdd extends SubscribingComponent {
  @ViewChild(CrePromptDialog) dialog: CrePromptDialog

  @Output() defaultGroupUpdate = new EventEmitter<GroupToken>()

  controls = {name: new FormControl(null, Validators.required)}
  form = new FormGroup(this.controls)

  private group: Group | null

  constructor(
    private groupTokenService: GroupTokenService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  show(group: Group) {
    this.group = group
    this.dialog.show()
  }

  submit() {
    if (!this.group) {
      console.error("Group token group id was not defined")
      return
    }

    const name = this.controls.name.value
    this.subscribe(
      this.groupTokenService.save(name, this.group.id),
      groupToken => this.defaultGroupUpdate.emit(groupToken.group)
    )
  }
}
