import {Component, ViewChild} from '@angular/core'
import {GroupService} from '../../services/group.service'
import {Group, GroupToken, Permission} from '../../../shared/model/account.model'
import {AccountService} from '../../../accounts/services/account.service'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {ActivatedRoute, Router} from '@angular/router'
import {ErrorHandler, ErrorService} from '../../../shared/service/error.service'
import {AlertService} from '../../../shared/service/alert.service'
import {AppState} from '../../../shared/app-state'
import {GroupTokenService} from "../../../accounts/services/group-token.service";
import {GroupTokenAdd} from "../../../groupTokens/group-tokens";

@Component({
  selector: 'cre-groups',
  templateUrl: './list.component.html',
  styleUrls: ['./list.component.sass']
})
export class ListComponent extends ErrorHandlingComponent {
  groups$ = this.groupService.all
  groupsEmpty = false
  currentGroupToken: GroupToken | null

  noDefaultGroupColumns = ['name', 'permissionCount', 'setAsDefaultButton', 'editButton']
  defaultGroupColumns = ['name', 'permissionCount', 'currentDefaultGroup', 'editButton']

  errorHandlers: ErrorHandler[] = [{
    filter: error => error.type === 'nodefaultgroup',
    consumer: () => this.alertService.pushWarning('Aucun groupe par défaut n\'a été défini sur cet ordinateur')
  }, {
    filter: error => error.type === 'exists-grouptoken-name',
    messageProducer: error => `Un ordinateur avec le nom '${error.name}' existe déjà`
  }]

  @ViewChild(GroupTokenAdd) groupTokenDialog: GroupTokenAdd

  constructor(
    private groupService: GroupService,
    private groupTokenService: GroupTokenService,
    private accountService: AccountService,
    private alertService: AlertService,
    private appState: AppState,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
    this.appState.title = 'Groupes'
  }

  ngOnInit(): void {
    this.subscribe(
      this.groupTokenService.current,
      token => this.currentGroupToken = token
    )
  }

  setDefaultGroup(group: Group) {
    this.groupTokenDialog.show(group)
  }

  isCurrentGroup(group: Group): boolean {
    return this.currentGroupToken && this.currentGroupToken.group.id == group.id
  }

  get columns(): string[] {
    return this.currentGroupToken ? this.defaultGroupColumns : this.noDefaultGroupColumns
  }

  get hasEditPermission(): boolean {
    return this.accountService.hasPermission(Permission.EDIT_USERS)
  }

  get hasAdminPermission(): boolean {
    return this.accountService.hasPermission(Permission.ADMIN)
  }
}
